
@import "@synerty/peek-plugin-base-js/src/styles/_variables";

:host {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    flex-shrink: 1;
    flex-basis: auto;
}

.action-buttons {
    display: flex;
    gap: $general_padding_1;
    margin-top: $general_margin_2;
}

nz-table {
    margin-bottom: $general_margin_2;
}

.setting-value {
    display: flex;
    align-items: center;
    
    nz-input-group {
        width: 100%;
    }
}